##
## R code for preprocessing epitope-to-MHC binding data set for the analysis
## presented in the manuscript
##
##    J. Palme, S. Hochreiter, and U. Bodenhofer.
##    KeBABS: an R package for kernel-based analysis of biological sequences
##    Bioinformatics 31:2574-2576, 2015. DOI: 10.1093/bioinformatics/btv176.
##

## load package(s)
library(Biostrings)

## read strong binders data from text file into data frame
URL <- "http://people.mpi-inf.mpg.de/~roomp/benchmarks/results.9mers-strong.txt"
mhc1data <- read.csv(URL, sep="\t", header=FALSE)

## select only the ones related to HLA-A*0201
a0201rawdata <- mhc1data[which(mhc1data$V2 == "A0201"), ]

## create DNAStringSet from sequences
a0201strongseqs <- AAStringSet(a0201rawdata$V4)

## add names to DNAStringSet
names(a0201strongseqs) <- paste(a0201rawdata$V3, a0201rawdata$V1, sep="_")

## show DNAStringSet
a0201strongseqs

## create label vector
a0201strongy <- rep(-1, length(a0201strongseqs))
a0201strongy[which(a0201rawdata$V3 == "binder")] <- 1

## write to R workspace file
save(a0201strongseqs, a0201strongy, file="MHC_I_A0201_Strong.RData")
